@@ -47,6 +47,7 @@
 #include <getopt.h>
 #include <sys/stat.h>
 #include <sys/time.h>
+#include <sys/types.h>
 #include <time.h>
 #include <signal.h>
 
@@ -173,7 +174,7 @@ weechat_display_usage ()
           "by colons (in this order: config, data, cache, runtime)\n"
           "                           (environment variable WEECHAT_HOME is "
           "read if this option is not given)\n"
-          "  -t, --temp-dir           create a temporary WeeChat home"
+          "  -t, --temp-dir           create a temporary WeeChat home "
           "directory and delete it on exit\n"
           "                           (incompatible with option \"-d\")\n"
           "  -h, --help               display this help\n"
@@ -610,6 +611,11 @@ weechat_init (int argc, char *argv[], void (*gui_init_cb)())
     weechat_first_start_time = time (NULL); /* initialize start time        */
     gettimeofday (&weechat_current_start_timeval, NULL);
 
+    /* set the seed for the pseudo-random integer generator */
+    srand ((weechat_current_start_timeval.tv_sec
+            * weechat_current_start_timeval.tv_usec)
+           ^ getpid ());
+
     signal_init ();                     /* initialize signals               */
     hdata_init ();                      /* initialize hdata                 */
     hook_init ();                       /* initialize hooks                 */
